<?php

App::uses('AppShell', 'Console/Command');

App::uses('Cybertill', 'EvCybertill.Lib');

class CybertillShell extends AppShell {

/**
 * Sync the stock so that the stock on the site matches with the stock in cybertill.
 */
	public function syncStock() {
		$Cybertill = new Cybertill();

		$Cybertill->syncStock();
	}

/**
 * Use this shell command to check the stock of a specific item in cybertill. Uses the details in the config
 * to establish a connection to cybertill and checks for stock of the provided SKU.
 * @param  arg[0] The SKU of the item to check stock of.
 */
	public function checkStock() {
		$Cybertill = new Cybertill();

		if (!empty($this->args[0])) {
			$sku = $this->args[0];

			$stock = $Cybertill->checkStock($sku);

			if ($stock['success'] === true) {
				$this->out("\n Product with sku: " . $sku . ' has ' . $stock['stock']->item->stock . " items in stock. \n");
				$this->out("\n Product with sku: " . $sku . ' has ' . $stock['stock']->item->reserved . " items reserved. \n");
			} else {
				$this->out("\n Product with sku: " . $sku . " has no items in stock. \n");
			}
		}
	}

/**
 * Sync the stock of a specific item so that the item on the site matches the item in cybertill.
 * @param  arg[0] The SKU of the item to sync with.
 * @param  arg[1] The model of the item. E.g. 'EvShop.Variant'
 */
	public function syncItemStock() {
		$Cybertill = new Cybertill();

		if (!empty($this->args[0]) && !empty($this->args[1])) {
			$sku = $this->args[0];
			$itemModel = $this->args[1];

			$ItemModel = EvClassRegistry::init($itemModel);

			$item = $ItemModel->find(
				'first',
				[
					'conditions' => [
						$ItemModel->alias . '.sku' => $sku
					]
				]
			);

			if (!empty($item)) {
				$Cybertill->syncItemStock($sku, $item, $ItemModel);
			}
		} else {
			$this->out("\nPlease provide an sku and the model the sku belongs to.\n");
		}
	}

/**
 * Use this shell command to set the stock of an item in cybertill. The stock is set to the specified value
 * instead of incrementing or decrementing the value currently in cybertill. The maximum and minimum values
 * are able to be set through this command.
 * @param  arg[0] The SKU of the tiem to set the stock of
 * @param  arg[1] The amount of stock to set.
 */
	public function setStock() {
		$Cybertill = new Cybertill();

		if (!empty($this->args[0]) && isset($this->args[1])) {
			$sku = $this->args[0];
			$stockAmount = $this->args[1];

			$Cybertill->setStock($sku, $stockAmount);
		} else {
			$this->out("\nPlease provide an sku and the amount of stock you want the product to have.\n");
		}
	}
}
